Reedy has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/324350

Change subject: Replace FSRepo with FileRepo
......................................................................

Replace FSRepo with FileRepo

Change-Id: Id6ca36cfa14077efc3d07fd5129ad9e4cc224e2c
---
M tests/phpunit/includes/media/MediaWikiMediaTestCase.php
1 file changed, 2 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/50/324350/1

diff --git a/tests/phpunit/includes/media/MediaWikiMediaTestCase.php 
b/tests/phpunit/includes/media/MediaWikiMediaTestCase.php
index e854ab5..91e8459 100644
--- a/tests/phpunit/includes/media/MediaWikiMediaTestCase.php
+++ b/tests/phpunit/includes/media/MediaWikiMediaTestCase.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * Specificly for testing Media handlers. Sets up a FSFile backend
  */
 abstract class MediaWikiMediaTestCase extends MediaWikiTestCase {
 
@@ -29,7 +29,7 @@
                        'containerPaths' => $containers,
                        'tmpDirectory' => $this->getNewTempDirectory()
                ] );
-               $this->repo = new FSRepo( $this->getRepoOptions() );
+               $this->repo = new FileRepo( $this->getRepoOptions() );
        }
 
        /**
@@ -1,6 +1,6 @@
 <?php
 /**
- * Specificly for testing Media handlers. Sets up a FSFile backend
+ * Specificly for testing Media handlers. Sets up a FileRepo backend
  */
 abstract class MediaWikiMediaTestCase extends MediaWikiTestCase {

-- 
To view, visit https://gerrit.wikimedia.org/r/324350
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Id6ca36cfa14077efc3d07fd5129ad9e4cc224e2c
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Reedy <re...@wikimedia.org>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to